/*
 * Copyright (c) 2006 Suguru ARAKAWA. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package jp.ac.hosei.k.cis.java2005.dita;

import java.text.MessageFormat;

/**
 * バイナリエディタで共通に使われるユーティリティ。
 * @author arakawa
 * @version $Id: BinaryEditorUtil.java,v 1.2 2005/11/17 05:14:12 java2005 Exp $
 */
public class BinaryEditorUtil {

    private static final String EOF = "--"; //$NON-NLS-1$

    private static final String[] BYTES;
    static {
        BYTES = new String[256];
        for (int i = 0; i < BYTES.length; i++) {
            BYTES[i] = createHexString(i);
        }
    }
    
    /**
     * 整数を2桁の16進数表示に変換する。
     * @param n 変換する数値
     * @return 16進表記の数値
     */
    public static String toHexString(int n) {
        if (n < -1 || n >= 256) {
            throw new IllegalArgumentException(MessageFormat.format(
                Messages.getString("BinaryEditorUtil.out_of_range"), //$NON-NLS-1$
                new Object[]{Integer.valueOf(n)}));
        }
        if (n == -1) {
            return EOF;
        }
        else {
            return BYTES[n];
        }
    }

    /**
     * インスタンス化の禁止。
     */
    private BinaryEditorUtil() {
        super();
    }

    /**
     * 整数を2桁の16進数表示に変換する。
     * @param n 変換する数値
     * @return 16進表記の数値
     */
    private static final String createHexString(int n) {
        return Integer.toHexString((n >>> 4) & 0x0f) + Integer.toHexString(n & 0x0f);
    }
}
