/*
 * Copyright (c) 2006 Suguru ARAKAWA. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package jp.ac.hosei.k.cis.java2005.dita;

import java.io.File;

/**
 * バイナリエディタのビューが持つべきインターフェース。
 * @author arakawa
 * @version $Id: BinaryEditorView.java,v 1.1 2005/11/17 05:14:12 java2005 Exp $
 */
public interface BinaryEditorView {

    /**
     * このビューに、ファイルを開く操作を要求する。
     * @return ビューがユーザから取得した、開くべきファイル
     */
    File requestFileOpen();

    /**
     * このビューに、ファイルを保存する操作を要求する。
     * @return ビューがユーザから取得した、保存すべき対象のファイル
     */
    File requestFileSave();

    /**
     * このビューに、プログラムを終了する操作を要求する。
     * @return ユーザが終了を選択した場合は <code>true</code>
     */
    boolean requestExit();

    /**
     * このビューに、指定したファイルを読み込んだことを通知する。
     * @param f 読み込んだファイル
     */
    void notifyFileOpened(File f);

    /**
     * このビューに、指定したファイルにデータを保存したことを通知する。
     * @param f 保存したファイル
     */
    void notifyFileSaved(File f);

    /**
     * このビューに、エラーが発生したことを通知する。
     * @param summary エラーの概要
     * @param message エラーメッセージ
     */
    void notifyErrorOccurred(String summary, String message);

    /**
     * このビューのデータを変更する。
     * @param data 変更先のデータ
     */
    void setData(byte[] data);

    /**
     * このビューが持つデータを取得する。
     * @return 現在のデータ
     */
    byte[] getData();

}
