/*
 * Copyright (c) 2006 Suguru ARAKAWA. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package jp.ac.hosei.k.cis.java2005.dita.swing;

import java.awt.Color;
import java.util.Map;
import java.util.WeakHashMap;

import javax.swing.SwingConstants;
import javax.swing.table.DefaultTableCellRenderer;

/**
 * エディタのアドレス部分をレンダリングするレンダラ。
 * @author arakawa
 * @version $Id: AddressCellRenderer.java,v 1.2 2005/11/17 05:23:10 java2005 Exp $
 */
public class AddressCellRenderer extends DefaultTableCellRenderer {
    
    private static final long serialVersionUID = 1L;
    private static final int ADDRESS_LENGTH = 8;
    private final Map cache;

    /**
     * インスタンスを生成する。
     */
    public AddressCellRenderer() {
        super();
        this.cache = new WeakHashMap();
        this.setHorizontalAlignment(SwingConstants.RIGHT);
        this.setBackground(new Color(0xe0e0e0));
    }

    /**
     * 値が設定される際に呼び出される。
     * @param value 設定する値
     */
    protected void setValue(Object value) {
        if (value instanceof Integer){
            String address = (String) this.cache.get(value);
            if (address == null) {
                int n = ((Integer) value).intValue();
                address = toAddressString(n);
                this.cache.put(value, address);
            }
            super.setValue(address);
        }
        else {
            super.setValue(String.valueOf(value));
        }
    }
    
    /**
     * 数値をアドレス形式の文字列に変換する。
     * @param n 変換する数値
     * @return 変換後の文字列
     */
    private String toAddressString(int n) {
        String hex = Integer.toHexString(n);
        StringBuffer buf = new StringBuffer();
        buf.append("0x"); //$NON-NLS-1$
        for (int i = hex.length(); i < ADDRESS_LENGTH; i++) {
            buf.append("0"); //$NON-NLS-1$
        }
        buf.append(hex);
        return buf.toString();
    }
}
